@@ -14,6 +14,8 @@ use std::{env, fmt, fs, io, mem, ops::Deref};
 #[cfg(not(target_os = "emscripten"))]
 use uuid::Uuid;
 
+#[doc(hidden)]
+pub use cap_std::ambient_authority_known_at_compile_time;
 pub use cap_std::{ambient_authority, AmbientAuthority};
 
 /// A directory in a filesystem that is automatically deleted when it goes out
